%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% This package contains software developed during 
%% LATEX projet 2008-2011
%% www.com.univ-mrs.fr/LOPB/LATEX
%% 02/12/2012, LR : contents.m updated
%% 05/12/2012, LR
%% 24/09/2010, AD : "just arrived at harbour" release
%% 24/08/2012, AD: Submission of the paper to JTECH and first release of LATEXtools
%%                 merging the package for EGU2011 modified for editing of figure of the paper
%%                 and dir LATEX/LATEX10/LATEX_MATLAB_tools 
%% 03/09/2012, FN+AD: bathymetry data added
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
%% LR : louise.rousselet@etu.univ-amu.fr
%% FN : francesco.nencioli@univ-amu.fr
%% AD : andrea.doglioli@univ-amu.fr
%% AP : anne.petrenko@univ-amu.fr
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% LIST of SCRIPTS and FUNCTIONS
%
%
%%  map_ARGOS        Plots trajectories of ARGOS buoys
%    plot_ARGOS      Help to get all the necessary infos from the Argos file - **.txt
%     load_ARGOS     Load data from Argos file
%
%%  map_FSLE         Plots FSLE manifolds
%   plot_FSLE        Help to get FSLE infos
%    load_FSLE       Load data from FSLE
%
%%  map_ADCP         Plots ADCP vectors
%   plot_ADCP        Help to get all the necessary infos from the ADCP file
%    load_ADCP       Load data from ADCP file
%
%%  map_SF6          Plots map of concentration
%   plot_SF6         Help to get infos to plot data of the SF6 concentration
%    load_SF6        Load data of the SF6 validated data
%
%%  map_AVHRR        Plots map of SST
%   plot_AVHRR       Helps to draw AVHRR frame
%    load_AVHRR      Load AVHRR data
%
%%  map_VESSEL       Plots Vessel positions
%    plot_VESSEL     Help to get vessel infos to plot vessel positions
%     load_VESSEL    Load vessel data
%
%%  map_BATHY        Add high resolution isobath for NW Mediterranean
%    plot_BATHY      Help to draw high res isobaths
%     load_BATHY     data from BATHY_NWMED directory
%
%%  map_FSLE_ADCP     Plot geographical map with FSLE-ADCP manifolds
%    plot_FSLE
%    plot_ADCP
%     
%%  map_FSLE_ARGOS    Plot geographical map with FSLE-ARGOS manifolds
%    plot_FSLE
%    plot_ARGOS
%%  make_route       Draws a route and calculate time between stations
%
%%  make_clean_ADCP  Helps in positioning the cuts in ADCP data
%    clean_ADCP      Script for cutting ADCP data
%     regroup_ADCP   Script for matching data from different ADCP transects of a same cruise 
%
%%  Calcul_Release_SF6                     Helps in calculation of a Lagrangian (spiral) route 
%
%    lecture_trame_fichier_bateau          Load boat position
%    lecture_trame_fichier_bateau_tethys   Reading boat (Tethys boat) position
%    lecture_trame_fichier_bouee           Reading buoys position
%    lecture_trame_fichier_bouee_thetys    Reading (Tethys boat) buoys position
%    calcule_spirale_v2                    Computes a spiral
%    conversion_spirale                    Conversion from cartesian coordinates to polar
%    calcul_consignes                      Helps in calculation of navigation instructions to join the next spiral point
%    uv_2_cap                              Calculate u and v direction
%    Trace_Spirale                         Help to draw spirale
%    Trace_Bateau                          Help to draw boat trace
%    TB & TB_tethys                        Read and draw boat trace
%
%%  SamplingSpiral.m           Calculates the Lagrangian (spiral) tracer mapping
%    CenterOfEddy_finder       Help estimate the Center of the Eddy and save the transect variables
%    SpiralCalculator          Compute a spirale with defined corners,longitudinal and latitudinal spacing
%
%
%%  CenterOfEddy_finder        Help estimate the Center of the Eddy and save the transect variables
%
%%  clean_ADCP                 Cut ADCP data and save clean ADCP data from all transect
%
%%  lagrangian_navigation                      Helps in calculation of a Lagrangian (spiral) route 
%
%    lecture_trame_fichier_bouee_tethys       Reading buoys (Tethys boat) position
%    lecture_trame_fichier_bateau_tethys      Reading boat (Tethys boat) position
%    Calcul_consignes                         Helps in calculation of navigation instructions to join the next spiral point   
%    Trace_Carte                              Help to draw map
%    Trace_Spirale                            Help to draw spirale
%    Trace_Bateau                             Help to draw boat trace
%
%%  Lagrangian_Navigation_DEMO              Demo program of Calcul SF6
%
%   lecture_trame_fichier_bouee            Load buoys position
%   lecture_trame_fichier_bateau           Load boat position
%   calcule_spirale_v2                     Computes a spiral
%   conversion_spirale                     Conversion from cartesian coordinates to polar
%   Trace_Carte                            Help to draw map
%   Trace_Spirale                          Help to draw spirale
%
%%  Lagrangian_Reconstitution         Routine to plot the SF6 lagragrangian spiral
%
%%  plot_lonlat_Saved              Plot a the longitude and latitude with respect the number of measurement
%
%%  Reconstitution            Plots  the boat and buoy tracks in lat/lon  coordinate   system    togheter    with
%%                            buoy  track in the lagrangian  reference  system of the buoy
%    lecture_trame_fichier_bouee_tous
%    lecture_trame_fichier_bateau_tous
%    calcule_spirale
%
%%  reconstitution_2007       Same as Reconstitution for 2007 data
%
%%  Reconstitution_ARGOS      Same as Reconstitution for ARGOS buoy
%
%%  Reconstitution_ninebuoys  Same as Reconstitution for nine buoys
%
%%  Reconstitution_old        Old version of Reconstitution ???
%
%%  Reconstitution_Sf6        Plots  the sampling points of SF6 in the lagrangian reference frame of the Iridium buoy
%
%%  Regroup_ADCP              Create a final .mat file, gathering all the transects and interpolating the vectors uv on a chosen vertical profil
%
%%  SamplingSpiral            Plot the LATEX spiral of SF6 sampling
%
%%  Lagrangian_Navigation      Helps in calculation of a Lagrangian (spiral) route
%    conversion                Conversion position l_cms in position centieme l
%    decideg_to_degmin         Convert geographical coordinate from decimal degrees to degrees minutes
%    degmin_to_decideg         Convert geographical coordinate from degrees minutes to decimal degrees
%    degminsec_to_decideg      Convert geographical coordinate from degrees minutes secondes to decimal degrees
%
%%  Lagrangian_Reconstitution  Routine to plot the SF6 lagragrangian spiral
%    calcule_spirale_v2
%
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

