%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%    LATEX track plotter    %%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% This  script  plots  the boat and buoy tracks in 
% lat/lon  coordinate   system    togheter    with
% buoy  track in the lagrangian  reference  system 
% of the buoy.
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% 05/09/01 AD: second version for LATEX2010
%              some bugs corrected
% 06/07/07 AD: first version LATEX00 with commented 
%              lines for sensivity tests
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% input : save_spir_1162007_sansNaN.asc
%         concat_radiateur_sansNaN.asc
%
% output: one .eps file
%       3 color codes for vessel track
%       ccode=1 > blue
%       ccode=2 > blue->red increasing with time
%       ccode=3 > blue->red increasing with time 
%                 interval between vessel positions
%
% remarks: M_MAP package is required
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
clear;
%close all;
%
load ../Bouee_NicolasMartin/nine_buoys.txt

id=nine_buoys(:,1);
n=nine_buoys(:,12);

timeb=datenum(nine_buoys(:,4),nine_buoys(:,3),nine_buoys(:,2),nine_buoys(:,5),nine_buoys(:,6),0)

n=nine_buoys(:,12);

dlat=nine_buoys(:,7);
mlat=nine_buoys(:,8);
[inilat]=degmin_to_decideg(dlat,mlat);

dlon=nine_buoys(:,9);
mlon=nine_buoys(:,10);
[inilon]=degmin_to_decideg(dlon,mlon);



dirin='../Bouee_NicolasMartin/';
for ib=1:9
ib    

interval=[timeb(ib) timeb(ib)+1/24];

figure(1);%subplot(1,2,1);hold on;
[lat,lon,time_id]=plot_ARGOS(dirin,300034012011820,'ro-',interval);


time_Iridium=min(time_id);
lon_Iridium=min(lon);
lat_Iridium=min(lat);


%distance calculation betweeb Iridium buoy and other buoy
[s,a12,a21] = m_idist(lon_Iridium,lat_Iridium,inilon,inilat);
theta=(90-a12)*pi/180;
[distx,disty]=pol2cart(theta,s);%[m]
distx=distx./1000; %[km]
disty=disty./1000; %[km

%
figure(2);hold on%subplot(1,2,2);hold on;
title('buoy position in the lagrangian reference frame with Iridium ad the center')
plot(distx(ib),disty(ib),'+');
plot(0,0,'ro');
text(distx(ib),disty(ib),['#',num2str(id(ib)),' \it{',datestr(timeb(ib),'HH:MM'),'}']);

end

axis equal
xlabel('distance x [km]');
ylabel('distance y [km]');
text(-.15,-.15,'*','FontSize',30)
axis([-4 3 -3 3])
grid on
box on;
%
%- Figure Printing -%
print(1,'./figures/map_ADCP.png','-dpng','-r200');
%
disp(' ');
disp('----- END ---')