%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%  Script for cutting ADCP data
%%% 
%%%
%%% INPUT : LatexYYYY_DDMMaphi_new.mat file
%%%         clean_indices_DDMM.txt
%%%
%%% OUTPUT: LatexYYYY_DDMMaphi_new_cleaned.mat file
%%%
%%% ALGORITHM: Load the ADCP transect data treated by SAVED 
%%%            Load the file with the position of the cut 
%%%            Move the cut data for each transect
%%%            Put together the ADCP variables from each transect
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% 22/09/2010 : marion.kersale@univmed.fr
%%% Huge Credits : Ziyuan
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
help clean_ADCP.m
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
clear;close all;

%
%Load the ADCP data from all transects of the day
[fname,dirin]=uigetfile('..\ADCP\ADCP_Tethys\work\Latex2010_*aphi_new*.mat','Select the Mat file');
load([dirin,fname]);
%subfunction use to get all the necessary infos from the ADCP file
[lontotal,lattotal,timetotal,utotal,vtotal,amp,angle,nE,nC,gyro]=load_ADCP_Saved(dirin,fname,999);
% transform to the good form so that we can add the new data after
lontotal=lontotal';
lattotal=lattotal';
timetotal=timetotal';
Llon=length(lontotal);

%
%Load the indices file 
[indicename,indicedirin]=uigetfile('..\ADCP\ADCP_Tethys\work\clean_indices_*.txt','Select the transect');
info_transect=load([indicedirin,indicename]);
ntransect=info_transect(:,1);
n1=info_transect(:,2);
n2=info_transect(:,3);
Ln=length(n1);

%
%Add the number of the last transect if end_cut is diff of end transect
if n2(end)~=Llon;
    Ln=Ln+1;
end %end if


loop=0;
%
%Initialisation of the variables
u=0;    
v=0;
lon=0;     
lat=0;   
time=0;

%
%Move the cut data for each transect
for i=1:Ln;
    loop=loop+1;
    loop
  
    %First transect
    if loop==1;

        %No first transect if begin cut is equal to begin transect
        if n1(1)==1;
            u_interp=0;             
            v_interp=0;
            lon_interp=0;
            lat_interp=0;
            time_interp=0;
        %First transect if begin cut is diff of begin transect
        else
            u_interp=utotal(:,1:n1(1));             
            v_interp=vtotal(:,1:n1(1));             
            lon_interp=lontotal(:,1:n1(1));             
            lat_interp=lattotal(:,1:n1(1));             
            time_interp=timetotal(:,1:n1(1));     
        end %end if

    %Last transect if end cut is diff of end transect
    elseif loop==length(n2)+1;
        u_interp=utotal(:,n2(end):Llon);
        v_interp=vtotal(:,n2(end):Llon);
        lon_interp=lontotal(:,n2(end):Llon);
        lat_interp=lattotal(:,n2(end):Llon);
        time_interp=timetotal(:,n2(end):Llon);

    %Other transects in the middle
    else
        u_interp=utotal(:,n2(i-1):n1(i));
        v_interp=vtotal(:,n2(i-1):n1(i));
        lon_interp=lontotal(:,n2(i-1):n1(i));
        lat_interp=lattotal(:,n2(i-1):n1(i));
        time_interp=timetotal(:,n2(i-1):n1(i));
    end %end if

%
%Display the size of u before and after the cut for check
    disp(['before joint, size of u =',num2str(size(u))]);
    if loop==Ln;
        disp(['nbeging=',num2str(n2(end)),'  nend=',num2str(Llon)])
    else
        disp(['n1=',num2str(n1(i)),'  n2=',num2str(n2(i))])
    end %end if  
disp('')
disp(['size of u_interp =',num2str(size(u_interp))]);

%
%Function to put together the ADCP variables from each transect
[u]=joint_var(loop,u_interp,u);
[v]=joint_var(loop,v_interp,v);
[lon]=joint_var(loop,lon_interp,lon);
[lat]=joint_var(loop,lat_interp,lat);
[time]=joint_var(loop,time_interp,time);

%
%Display the size of u to test the size of var_total_interp before the regroup
disp('----------------') 
disp(['After joint, size of u =',num2str(size(u))]);

clear u_interp v_interp lon_interp v_interp time_interp amp angle truez iz nE nC gyro; 

end %end for

%
%Saved the CLEAN ADCP data from all transects of the day
dirout=dirin;
save([dirout,fname(1:end-4),'_cleaned.mat'],'u','v','lon','lat','time');

%
disp(' ');
disp('----- END ---')

