%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% Script to draw a SST map 
%%%
%%% INPUT : image SST.png
%%%         coastline .mat file
%%%
%%% OUTPUT: m_map figure 
%%%
%%% ALGORITHM: calcuate de projection and
%%%            plot
%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% 05/12/2012 : louise.rousselet@etu.univ-amu.fr : change loading files
%%% path
%%% 21/09/2010 : andrea.doglioli@univmed.fr : compatibility with others
%%%              tools
%%% Credits : anne.petrenko@univmed.fr and gilles.rougier@univmed.fr
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
help map_AVHHR
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
clear;close all;
%%
%- Data directory -%
dirin='AVHRR/';
filename='-var-ftp-pub-CMS_GOLTS-png_gray-201009091236.png';
%
%- Chosen Min and Max of the colormap and colorbar
Tmin=16;
Tmax=18;
%
%- Chosen lon et lat of the left bottom pixel of the entire figure (NWm
xim_min=2.45
yim_min=40.98
%
%- Caption position
lon_text=4.;
lat_text=42.2;
%
%- Map boundaries -%
lonmin=3;
lonmax=5;
latmin=42;
latmax=43.2;
%
%- Geographic projection for m_map -%
projection = 'mercator';
%
%- User coast in dirin -%
UserCoast='GOL.mat'; % in "sub_functions" directory
%
%- Plot the figure
figure(1); hold on; 
m_proj('mercator','lon',[lonmin lonmax],'lat',[latmin latmax])
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

plot_AVHRR(dirin,filename,Tmin,Tmax,xim_min,yim_min,lon_text,lat_text)

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%
%- Figure title -%
title(['LATEX 2010 map-AVHRR'])
%
%- NW Mediterranean High Resolution Isobaths -%
plot_BATHY('BATHYMETRY_NWMED/',[200 500]);
%
%- User's High Resolution Coastline -%
m_usercoast(UserCoast,'patch',[.7 .7 .7],'edgecolor','k');
%m_coast('patch',[.7 .7 .7],'edgecolor','k');
%
%- Geographical Axis -%
m_grid('box','fancy','tickdir','in');
xlabel('Longtitude');
ylabel('Latitude');
%
%- Figure Printing -%
print(1,'./figures/map_AVHRR.png','-dpng','-r200');
%
disp(' ');
disp('----- END ---')
