%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% Script for draw a geographical map with FSLE manifolds
%%%
%%% INPUT : coastline .mat file
%%%
%%% OUTPUT: m_map figure 
%%%
%%% ALGORITHM: calcuate de projection and
%%%            plot
%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% 05/12/2012 : louise.rousselet@etu.univ-amu.fr : change loading files
%%% path
%%% 21/09/2010 : andrea.doglioli@univmed.fr
%%% 17/09/2010 : francesco.nencioli@univmed.fr
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
help map_FSLE
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
clear;close all;
%%
%- FSLE Data directory -%
dirin_FSLE='FSLE/';
%
%- Date of FSLE map
year=2010;
month=9;
day=22;
%
%- FSLE Caption position
lon_text=3.9;
lat_text=42.16;
%
%- ADCP Data directory -%
dirin_ADCP='ADCP/'; % To be changed to relative path
fname='final_ADCP_Saved.mat';
%
%- ADCP Time interval -%
interval=[datenum(2010,9,22,18,0,0) now];
%%% for IO check
% interval=[datenum(2010,9,20,20,15,22) datenum(2010,9,21,1,46,25)];
% interval2=[ datenum(2010,9,21,1,46,25) datenum(2010,9,21,7,11,25)];
%
%- Depth -%
depth=15 ;%[m] positive
%
%- Plot Options
myopt='b';
myopt2='r';
%
%- Legend Options
myscale=5;
legend_unit=0.2;
legend_lon=4.1;
legend_lat=42.5;
%
%- Map boundaries -%
lonmin=3;
lonmax=4.5;
latmin=42;
latmax=42.9;
%
%- Geographic projection for m_map -%
projection = 'mercator';
%
%- User coast in dirin -%
UserCoast='GOL.mat'; % in "sub_functions" directory
%
%- Plot the figure
figure(1); hold on; 
m_proj('mercator','lon',[lonmin lonmax],'lat',[latmin latmax])
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%
%
plot_FSLE(dirin_FSLE,year,month,day,lon_text,lat_text)
%
plot_ADCP(dirin_ADCP,fname,interval,depth,myopt,myscale,legend_unit,legend_lon,legend_lat);
%plot_ADCP(dirin_ADCP,fname,interval2,depth,myopt2,myscale,legend_unit,legend_lon,legend_lat);
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%
%- Figure title -%
title(['LATEX 2010 map-FSLE-ADCP'])
%
%- NW Mediterranean High Resolution Isobaths -%
plot_BATHY('BATHYMETRY_NWMED/',[200 500]);
%
%- User's High Resolution Coastline -%
m_usercoast(UserCoast,'patch',[.7 .7 .7],'edgecolor','k');
%m_coast('patch',[.7 .7 .7],'edgecolor','k');
%
%- Geographical Axis -%
m_grid('box','fancy','tickdir','in');
xlabel('Longtitude');
ylabel('Latitude');
%
%- Figure Printing -%
print(1,'./figures/map_FSLE_ADCP.png','-dpng','-r200');
%
disp(' ');
disp('----- END ---')
