%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% Script for draw a geographical map with FSLE manifolds
%%%
%%% INPUT : coastline .mat file
%%%
%%% OUTPUT: m_map figure 
%%%
%%% ALGORITHM: calcuate de projection and
%%%            plot
%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% 05/12/2012 : louise.rousselet@etu.univ-amu.fr : change loading files
%%% path
%%% 21/09/2010 : andrea.doglioli@univmed.fr
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
help map_FSLE_ARGOS
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
clear;close all;
%%
%- FSLE Data directory -%
dirin_FSLE='FSLE/';
%
%- Date of FSLE map -%
year=2010;
month=9;
day=23;
%
%- Caption position
lon_text=3.65;
lat_text=41.9;
%
%- ARGOS Data directory -%
dirin_ARGOS='ARGOS/';
%
%- Buoy identifiers' list -%
%%% buoys taken at 15/09 and redeployed th 18/9 dureing FSLE exp
buoylist1=[48863 48903 48920 48939 48940]; 
%%% buoy lauched during II FSLE exp
buoylist2=[48893 48942 93263];
%%% buoy lauched during III FSLE exp
buoylist3=[93264 47834];
%
%- Time interval of the trajectories -%
interval=[datenum(2010,9,23,0,0,0) now];%datenum(2010,9,20,6,0,0)];
% interval1=[datenum(2010,9,19,10,0,0) now];
interval2=[datenum(2010,9,21,12,0,0) now];
% interval3=[datenum(2010,9,21,12,0,0) now];
% interval4=[datenum(2010,9,22,17,0,0) now];
interval5=[datenum(2010,9,22,19,0,0) now];
%
%- Map boundaries -%
lonmin=2.5;
lonmax=5;
latmin=41.;
latmax=43.2;
%
%- Geographic projection for m_map -%
projection = 'mercator';
%
%- User coast in dirin -%
UserCoast='GOL.mat'; % in "sub_functions" directory
%
%- Plot the figure
figure(1); hold on; 
m_proj('mercator','lon',[lonmin lonmax],'lat',[latmin latmax])
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%
% 
plot_FSLE(dirin_FSLE,year,month,day,lon_text,lat_text)
%
% Loop plotting trajectories with same options
for buoy_id=buoylist1
    plot_ARGOS(dirin_ARGOS,buoy_id,'ro',interval);
end
for buoy_id=buoylist2
    plot_ARGOS(dirin_ARGOS,buoy_id,'bo',interval);
end
for buoy_id=buoylist3
    plot_ARGOS(dirin_ARGOS,buoy_id,'go',interval);
end
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%
%- Figure title -%
title(['LATEX 2010 map-FSLE-ARGOS'])
%
%- NW Mediterranean High Resolution Isobaths -%
plot_BATHY('BATHYMETRY_NWMED/',[100 200 500]);
%
%- User's High Resolution Coastline -%
m_usercoast(UserCoast,'patch',[.7 .7 .7],'edgecolor','k');
%m_coast('patch',[.7 .7 .7],'edgecolor','k');
%
%- Geographical Axis -%
m_grid('box','fancy','tickdir','in');
xlabel('Longtitude');
ylabel('Latitude');
%
%- Figure Printing -%
print(1,'./figures/map_FSLE_ARGOS.png','-dpng','-r200');
%
disp(' ');
disp('----- END ---')
