%---------------------------------------------------------
% Hu & Nencioli Sept 2010
%---------------------------------------------------------
%
% - Load ADCP netcdf file;
% - Choose the transect limits;
% - Choose the vectors along the transect used for the COE;
% - Chose the number of points used for the COE;
% - Computes COE using maximum mean tangential velocity;
% - Saves the transect variables;
%
%---------------------------------------------------------
clear all;
close all;
addpath('./sub_functions/');
%---------------------------------------------------------
% User defined variables:
% - Velocity depth
disp('%***************************************************')
z=input('Enter the depth to process (-m): ');
%---------------------------------------------------------
disp(' ')
disp('%***************************************************')
in_type=input('Enter 1 to load velocities from a netcdf file, 2 to load a transect .mat file : ');
% Load .nc file
if in_type==1
	[fname,dirin]=uigetfile('../ADCP/*.nc','Select the ADCP dataset');
	[lon,lat,temp,u,v,amp,angle,nE,nC,gyro]=load_ADCP_Cascade(dirin,fname,999,z);	

	in_trans=input('Do you wanna load transects limits for this dataset? [y/n]','s');

	% Load transect .mat file if exist
	if in_trans=='y'
		[trans_name,trans_dirin]=uigetfile('../ADCP/*.mat','Select the transect');
		load([trans_dirin,trans_name],'s1','s2','n1','n2','cc')
	end
	% set transect limits
	if ~exist('n1','var') | ~exist('n2','var')
		n1=1;
		n2=size(u,1);
	end

	% Visualize transect limits
	m_proj('mercator','lon',[lon(1)-0.25 lon(end)+0.25],'lat',[lat(end)-0.5 lat(1)+0.5])
	figure(1)
	hold on
	m_gshhs_i
	m_grid('fancy')
	m_plot(lon,lat,'b-x')
	m_plot(lon(n1:n2),lat(n1:n2),'r-x')
	
	% Update transect limits if required
	disp(' ')
	disp('%***************************************************')
	disp(['The current transect limits are n1=',num2str(n1),' and n2=',num2str(n2)])

	% wait for user input
	user_input=input('Do you want to keep the current limits? [y,n]','s');
	% Compute new transect limits
	if user_input=='n'
		[n1 n2]=set_limits(lon,lat);
		disp(['The new transect limits are n1=',num2str(n1),' and n2=',num2str(n2)])

	end
	% cut velocity database to the selected limits
	u=u(n1:n2);
	v=v(n1:n2);
	amp=amp(n1:n2);
	temp=temp(n1:n2);
	lon=lon(n1:n2);
	lat=lat(n1:n2);

elseif in_type==2
	[trans_name,trans_dirin]=uigetfile('../ADCP/*.mat','Select the transect');
	load([trans_dirin,trans_name])
	% For plotting purposes
	u=U;
	v=V;
	lon=Lon;
	lat=Lat;

else
	error('You must enter 1 or 2!!!')
end
close all
%%---------------------------------------------------------
% Compute new COE limits if requested
if ~exist('s1','var') | ~exist('s2','var')
	s1=1;
	s2=size(u,1);
	cc=floor(size(u,1)/2);
end
m_proj('mercator','lon',[lon(1)-0.25 lon(end)+0.25],'lat',[lat(end)-0.1 lat(1)+0.1])
figure
m_grid('box','fancy')
hold on
m_gshhs_i
m_quiver(lon,lat,u,v,0,'color','b')
m_plot(lon(cc),lat(cc),'r*')
m_quiver(lon(s1:s2),lat(s1:s2),u(s1:s2),v(s1:s2),0,'color','r')

disp(' ')
disp('%***************************************************')
disp(['The current limits for the COE along the transect are s1=',num2str(s1),' and s2=',num2str(s2)])

% wait for user input
user_input=input('Do you want to keep them? [y,n]','s');
close all
if user_input=='n'
	[cc s1 s2]=set_vectors(lon,lat,u,v);
	disp(['The limits for the COE are s1=',num2str(s1),' and s2=',num2str(s2)])
end
%---------------------------------------------------------
% Center Of the Eddy estimate:
% - Set area limits
dside=max(abs(lon(cc)-lon(s1)),abs(lat(cc)-lat(s1)));

lonmin = lon(cc)-dside;
lonmax = lon(cc)+dside;
latmin = lat(cc)-dside;
latmax = lat(cc)+dside;
% - Define variables (plotting purposes)
U=u;
V=v;
Lon=lon;
Lat=lat;
% - Define variables for COE
u=u([s1:s2]);
v=v([s1:s2]);
pos(1,:)=lon([s1:s2]);
pos(2,:)=lat([s1:s2]);
% - Start COE
disp(' ')
disp('%***************************************************')

button='n';  % switch to exit the procedure and save the data
while button=='n'

	npoints=input('Enter the number of points for the COE grid: ');
	disp('	(Plotting the figure)')
	% define trial point positions depending on npoints
	dlon=(lonmax-lonmin)/(npoints-1);
	dlat=(latmax-latmin)/(npoints-1);

	lon=lonmin:dlon:lonmax;
	lat=latmin:dlat:latmax;
	% variables to compute the distance from the center ---
	R=6378.137;
	f=pi/180; % lat and lon multiplied by f to convert them into radians
	%------------------------------------------------------

	% define RMS to be compared with the one computed to decide if the
	% position of the center is good or not
	RMS=10000; %renewed every cycle
	% define a mean tg velocity to be compared with the computed one
	Mtg=0;
	for ii=1:length(lon) %for every lon
		for iii=1:length(lat) %for every lat
			for j=1:length(pos(1,:))
				% decompose into tan and rad components for different
				% centers
				%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
				% in future rewrite dx dy with m_lldist (like r(ii))!!!!!!!
				%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
				dy=R*acos(cos(lat(iii)*f)*cos(pos(2,j)*f)* ...
					cos(lon(ii)*f-lon(ii)*f)+sin(lat(iii)*f)*sin(pos(2,j)*f));
				dx=R*acos(cos(pos(2,j)*f)*cos(pos(2,j)*f)* ...
					cos(lon(ii)*f-pos(1,j)*f)+sin(pos(2,j)*f)*sin(pos(2,j)*f));
				% to prevent divide by zero warning
				dx(dx==0)=inf;
				%r(ii)=R*acos(cos(lat(iii)*f)*cos(pos(2,j)*f)* ...
				%	cos(lon(ii)*f-pos(1,j)*f)+sin(lat(iii)*f)*sin(pos(2,j)*f));
				%                lon(ii)              pos(1,j)                lat(iii)                pos(2,j)
				r(ii)=m_lldist([lon(ii) pos(1,j)],[lat(iii) pos(2,j)]);
				angle=(atan(dy/dx));
				%Set the angle of rotation of the reference system
				if lon(ii)>pos(1,j) & lat(iii)<pos(2,j)
					angle=pi-angle;
				elseif lon(ii)>pos(1,j) & lat(iii)>pos(2,j)
					angle=pi+angle;
				elseif lon(ii)<pos(1,j) & lat(iii)>pos(2,j)
					angle=2*pi-angle;
				end
				alpha(j)=angle*180/pi;
				%Positive par along transect direction;
				%Positive per to the left of radius (positive counterclockwise);
				radial(j)=u(j)*cos(angle)+v(j)*sin(angle);
				tangent(j)=-u(j)*sin(angle)+v(j)*cos(angle);
			end
			tmp_var=radial([1:1:end])/sqrt(length(radial([1:1:end])));
			temp_RMS=norm(tmp_var(~isnan(tmp_var)));
			%                temp_RMS=norm(radial([1:1:end]))/sqrt(length(radial([1:1:end])))
			temp_mean=mean(tangent(~isnan(tangent)));
			%                temp_mean=mean(tangent([1:1:end]))
			% compare the RMS with the previous one:
			% if it's smaller then save the positions of the center
			if temp_RMS<RMS
				RMS=temp_RMS;
				COE_RMS=[lat(iii) lon(ii)];
			end
			if temp_mean<Mtg
				Mtg=temp_mean;
				COE_Mtg=[lat(iii) lon(ii)];
			end
			map_Mtg(iii,ii)=temp_mean; % saved(depth,lat,lon) !!!!!!!!!
			map_RMS(iii,ii)=temp_RMS;
		end
	end
	%--------------- fix pcolor --------------------
	% colored cell centered at the data point!!!!!!!
	diffX=diff(lon);
	diffX=[diffX,diffX(1)];

	diffY=diff(lat);
	diffY=[diffY,diffY(1)];

	Xpc=lon-diffX/2;
	Ypc=lat-diffY/2;

	% create another line of data in X and Y so that all the data are colored
	Xpc=[Xpc,Xpc(end)+diffX(end)];
	Ypc=[Ypc,Ypc(end)+diffY(end)];
	varpc=[map_Mtg,map_Mtg(:,1)];
	varpc=[varpc;varpc(1,:)];
	%-----------------------------------------------

	% adjust pos var for quiver --------------------
	uv_lon=pos(1,:)';
	uv_lat=pos(2,:)';
	%-----------------------------------------------

	% Plot the data --------------------------------
	m_proj('mercator','lon',[Lon(1)-0.05 Lon(end)+0.05],'lat',[Lat(end)-0.1 Lat(1)+0.1])
	figure
	m_pcolor(Xpc,Ypc,varpc)
	shading flat
	hold on
	m_grid('box','fancy')
	m_gshhs_i
	m_quiver(Lon,Lat,U,V,0,'color',[.7 .7 .7])
	m_quiver(uv_lon,uv_lat,u,v,0,'color','k')
	m_plot(COE_Mtg(2),COE_Mtg(1),'r*','markersize',8,'linewidth',1.5)
	%-----------------------------------------------

	% Confirm the data -----------------------------
	button=input('Do you accept the COE estimate? [y/n] ','s');
	%-----------------------------------------------
end
close all

% Save the variables -----------------------------------
% - User specified output file name
disp(' ')
disp('%***************************************************')
disp('Save the transect')
disp(' ')
disp('%***************************************************')
[out_name,dirout]=uiputfile([dirin,'*.mat'],'Save file name');

save([dirout,out_name],'s1','s2','n1','n2','cc', ...
	'Lon','Lat','U','V', ...
	'u','v','uv_lon','uv_lat', ...
	'COE_Mtg','map_Mtg','lon','lat', ...
	'dirin','fname')
%-------------------------------------------------------
