%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% script to plot the LATEX spiral of SF6 sampling
%% Matlab and M_MAP needed
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% 09/09/2010 AD: remouved unuseful entry fname
% 07/09/2010 FN:new constrains
% 06/09/2010 GR AD new read buoy
% 05/09/2010 gilles.rougier@ifremer.fr & francesco.nencioli@univmed & AD:
%            removing of the correction bug scale factor of the center
% 01/09/2010 AD: changes discussed with Stephane Blain: distances in nm and units added in the propmpt,
% lat/lon of spiral points written in order from center to outside along
% the spiral and in the format for the bridge, function added to plot SF6
% concentration in real time.
% --/08/2010 nicolas.grima@univ-brest.fr: GUI
% 24/06/2010 AD: new algoritm for distances
% 28/05/2010 creation andrea.doglioli@univmed.fr & anne.petrenko@univmed.fr
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

clear all; close all;
help SamplingSpiralGui
%%
%====================================%
%- VARIABLES by default for the GUI -%
%====================================%-----------%
%- You have to change these variables to obtain -%
%- different spiral configurations.             -%
%------------------------------------------------%

%- Spiral parameters -%
ext_xlon =  30.0; % km
ratio    =   0.8; % ratio between X and Y dimensions
maxdist  = 200.0; % [nm]
rotangle =   30.0; % degree N anticlockwise

dataplot = 'buoy';
%dataplot = 'adcp';

% %- buoys file name -%
% fname_latex='LATEX_20100902T121502.tmp';
% m1 =    9;
% d1 =   11;
% y1 = 2008;

%%
%==========================================================%
%- Change things bellow this line if you know what you do -%
%==========================================================%

%%
%============%
%- Constants-%
%============%

%- paths -%
%addpath('./sub_functions/');
dirin='..\Bouee_NicolasMartin\';
dirout='./';

%- User coast in dirin -%
UserCoast='./GOL.mat'; % in "sub_functions" directory

%- area limits -% (in degres)
lon_min =  3.45;
lon_max =  3.9;
lat_min = 42.4;
lat_max = 42.80;

%- Geographip projection for m_map -%
projection = 'mercator';
%AD: tested different projection: non sensitivity
%projection = 'lambert';
%projection = 'ortho';
%projection = 'sinusoidal';

%- Figures Identifiers -%
fid1 = figure('Visible','off');
fid2 = figure('Visible','off');
%NG: fid3 = figure('Visible','off');

%%
%==========================================================%
%- Step 1 - Choose your data and geographic area with GUI -%
%==========================================================%
while (1)
      
%     prompt = {['data type (buoy or adcp) = ' dataplot], ...
%               ['directory = ', dirin]                 , ...
%               ['file name    = ' fname_latex]         , ...
%              ['day = ' num2str(d1)]                  , ...
%              ['year = ' num2str(y1)]                 , ...
    prompt = {['data type (buoy or adcp) = ' dataplot], ...
              ['directory = ', dirin]                 , ...              ['month  = ' num2str(m1)]               , ...
              ['lon_min = ' num2str(lon_min)]         , ...
              ['lon_max = ' num2str(lon_max)]         , ...
              ['lat_min = ' num2str(lat_min)]         , ...
              ['lat_max = ' num2str(lat_max)]         , ...
              ['projection (m_map) = ' projection]    };
          
    dlg_title = 'Latex spiral tool (step 1)';
    
    num_lines = 1;
    
%     def       = {dataplot        , ...
%                  dirin           , ...
%                  fname_latex     , ...
%                 num2str(m1)     , ...        
%                 num2str(d1)     , ...
%                 num2str(y1)     , ...
    def       = {dataplot        , ...
                 dirin           , ...
                 num2str(lon_min), ...
                 num2str(lon_max), ...
                 num2str(lat_min), ...
                 num2str(lat_max), ...
                 projection}     ;
             
    answer    = inputdlg(prompt,dlg_title,num_lines,def);

    if (isempty(answer))
      %=
      %- Exit program -%
      %=
      break;
    else
%       dataplot                 = answer{1};
%       dirin                    = answer{2};
%       fname_latex              = answer{3};
%       [m1 status_m1]           = str2num(answer{4});
%       [d1 status_d1]           = str2num(answer{5});
%       [y1 status_y1]           = str2num(answer{6});
%       [lon_min status_lon_min] = str2num(answer{7});
%       [lon_max status_lon_max] = str2num(answer{8});
%       [lat_min status_lat_min] = str2num(answer{9});
%       [lat_max status_lat_max] = str2num(answer{10});
%       projection               = answer{11};
      dataplot                 = answer{1};
      dirin                    = answer{2};
      [lon_min status_lon_min] = str2num(answer{3});
      [lon_max status_lon_max] = str2num(answer{4});
      [lat_min status_lat_min] = str2num(answer{5});
      [lat_max status_lat_max] = str2num(answer{6});
      projection               = answer{7};
    end
    
%     if ((strcmp(dataplot,'buoy') || strcmp(dataplot,'adcp')) && ...
%         exist([dirin fname_latex '.txt'],'file') && ...
     if ((strcmp(dataplot,'buoy') || strcmp(dataplot,'adcp')) && ...        status_m1       && status_d1 && status_y1  && ...
        status_lon_min  && status_lon_max && ...
        status_lat_min  && status_lat_max && ...
        (lon_min < lon_max) && (lat_min < lat_max))
      break;
    elseif (~strcmp(dataplot,'buoy') && ~strcmp(dataplot,'adcp'))
        disp('Please enter buoy or adcp for dataplot!');
    elseif (exist([dirin fname_latex '.txt'],'file'))
        disp('Please enter correct directory and filename!');
    else
      disp('Please enter correct values!');
    end

end
  
%- Exit the program if cancel is selected -%
if (isempty(answer))
    disp 'Exit the Latex Spiral Tool Gui'
    break;
end

%%
%============%
%- main GUI -%
%============%
lonsc = 3.5%lon_min + (lon_max - lon_min) * 0.5;
latsc = 42.5%lat_min + (lat_max - lat_min) * 0.5;

while (1)
    
    %- Parameter Box -%
  while (1)
      
    prompt = {['ext_xlon [km]= ' num2str(ext_xlon)], ...
              ['ratio    [  ]= ' num2str(ratio)], ...
              ['maxdist  [nm]= ' num2str(maxdist)], ...
              ['rotangle [oN]= ' num2str(rotangle)], ...
              ['Spiral center longitude = ' num2str(lonsc)], ...
              ['Spiral center latitude = ' num2str(latsc)]};
          
    dlg_title = 'Latex spiral tool';
    
    num_lines = 1;
    
    def       = {num2str(ext_xlon),...
                 num2str(ratio),...
                 num2str(maxdist),...
                 num2str(rotangle), ...
                 num2str(lonsc), ...
                 num2str(latsc)};
             
    answer    = inputdlg(prompt,dlg_title,num_lines,def);

    if (isempty(answer))
      %=
      %- Exit program -%
      %=
      break;
    else
      [ext_xlon status_xlon]    = str2num(answer{1});
      [ratio    status_ratio]   = str2num(answer{2});
      [maxdist status_maxdist]  = str2num(answer{3});
      [rotangle status_rotangle]= str2num(answer{4});
      [lonsc status_lonsc]      = str2num(answer{5});
      [latsc status_latsc]      = str2num(answer{6});
    end
    
    if (status_xlon    && status_ratio    && ...
        status_maxdist && status_rotangle && ...
        status_lonsc   && status_latsc)
      break;
    else
      disp('Please enter real values!');
    end

  end
 
   %- Exit the Gui tool -%
   if (isempty(answer))
     disp 'Exit the Latex Spiral Tool Gui'
     break;
   end
    
    %%
    %====================================%
    %- script to plot buoy or adcp data -%
    %====================================%
    %- Open figure -%
    close(fid1);
    figure(1);
    hold on
    
    subplot(1,4,[1 2 3]);
    
    %- M_map projection and representation of the coast -%
    m_proj(projection,'lon',[lon_min lon_max],'lat',[lat_min lat_max]);
    m_grid('box','fancy','tickdir','in');
    
    [xc yc] = m_ll2xy(lonsc,latsc);
        
    hold on;
    
    if exist(UserCoast,'file')
        m_usercoast(UserCoast,'patch',[.7 .7 .7],'edgecolor','k');
    else
        m_coast('patch',[0.7 0.7 0.7],'edgecolor','k');
    end
    
    %- call the routine selected by "dataplot" to plot the data -%
    if strcmp(dataplot,'buoy')
        %- plot buoys positions on figure fid1 -%
        %plot_Argos;
        map_ArgosFloats
    elseif strcmp(dataplot,'adcp')
        %- plot adcp measurements on figure fid1 -%
        plot_ADCP_center;
    end
    
    %- resize the figure window -%
    figure(1);
    scrsz = get(0,'ScreenSize');
    set(1,'Position',[scrsz(3)/8 scrsz(4)/4 scrsz(3)/1.5 scrsz(4)/1.5]);
    
    %- Add title, labels and text -%
    title(['Cruise Latex 2010'],'FontWeight','bold','FontSize',14);
    xlabel('Longitude', 'FontWeight','bold','FontSize',14);
    ylabel('Latitude' , 'FontWeight','bold','FontSize',14);
    
    %%
    %====================================================%
    %- Compute the spiral centered on xc,yc coordinates -%
    %====================================================%

    %%%%%%%%%%%%%%%%%%%%%%%%%
    %%% Andrea OLD method %%%
    %%%%%%%%%%%%%%%%%%%%%%%%%
%     %- Infiny value to maximize while loop -%
%     totdistanceKM2 = Inf('double');
%     pasX = 1.; %minimal DX[km]
%     DpasX = 1.; %increment [km]
%     near = 1.; %interval around choosen center [km]
%     
%     while totdistanceKM2 >= maxdist * 1.852;
%         
%         [totdistanceKM,xx,yy] = funct_sampling(pasX,ext_xlon,maxdist,ratio,near); %[km]
%         
%         totdistanceKM2 = totdistanceKM; %[km]
%         
%         pasX = pasX + DpasX; %[km]
%         
%     end
     
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%
    %%% Francesco NEW method %%%
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%  
    totdistanceKM2 = 0;
    pasX = 1; %minimal DX[km]
    near = 1; %interval around choosen center [km]
    
    xn=1;
    while totdistanceKM2 <= maxdist * 1.852;
        
	    pasX=ext_xlon/(2*xn);
	    pasY=(ext_xlon*ratio)/(2*xn);
        [totdistanceKM,xx,yy] = SpiralCalculator(xn,pasX,pasY); %[km]
        
        totdistanceKM2 = totdistanceKM; %[km]
        
        xn= xn + 1; %[km]
    end
     %%%%%%%%%%%%%%%%%%%%%%%%%%%%

    
    %%
    %============%
    %- Rotation -%
    %============%
    %xx = + xx.*cos(rotangle*pi/180) + yy.*sin(rotangle*pi/180);
    %yy = - xx.*sin(rotangle*pi/180) + yy.*cos(rotangle*pi/180);
    %dist1=sqrt((xx(29)).^2+(yy(29))^2)
    xx =  xx.*cosd(rotangle)-yy.*sind(rotangle);
    yy =  xx.*sind(rotangle)+yy.*cosd(rotangle);
    xx2 =  xx.*cosd(rotangle)-yy.*sind(rotangle);
    yy2 =  xx.*sind(rotangle)+yy.*cosd(rotangle);
    [tt,rr]=cart2pol(xx,yy);
    [xx3,yy3]=pol2cart(tt+rotangle*pi/180,rr);
    %dist2=sqrt((xx(29)).^2+(yy(29))^2)
    figure
    plot(xx,yy)
    axis equal
    figure
    plot(xx2,yy2)
    axis equal
    figure
    plot(xx3,yy3)
    axis equal
    
    %%
    %=====================================================%
    %- Open a second figure to represent only the spiral -%
    %=====================================================%
    figure(fid2);
    hold off;
    
    %--------------------------%
    %- plot the spiral center -%
    %--------------------------%
    plot(xc,yc,'*');
    hold on;
    
    %-------------------%
    %- plot the spiral -%
    %-------------------%
    plot(xx,yy,'o-');
    
    %---------------------------------------------%
    %-  convertion to lon lat, see help m_lldist -%
    %---------------------------------------------%
    [trah,mysize] = size(xx);
    [lonc,latc]   = m_xy2ll(xc,yc);
    
    %---------------------------------------------%
    %- Convertion from cartesian coordinates to polar -%
    %---------------------------------------------%
    %%%distance W-E in [km] @lat_min betweem origine and  
    %%%center of the spiral
    DDX=m_lldist([lon_min lonc],[lat_min lat_min]);%[km]
    %%%distance S-N in [km] @lon_min (not important) betweem origine
    %%%and center of the spiral
    DDY=m_lldist([lon_min lon_min],[lat_min latc]);%[km]
    %%% distance W-E in [km] @lat_min betweem origine and
    %%% points of the spiral
    DDXX=(DDX+xx); %[km]
    %%% distance S-N in [km] lon_min (not important) between origine
    %%% and points of the spiral
    DDYY=(DDY+yy); %[km]
    
    %%%distance in km of 1 degree of lon @ lat_min
    DXWINDOW=m_lldist([lon_min lon_min+1],[lat_min lat_min]);%[km]
    DLON=DDXX/DXWINDOW;%%%conversion in lon degree @lat_min of DDXX
    %%%distance in km of 1 degree of lat @ lon_min
     DYWINDOW=m_lldist([lon_min lon_min],[lat_min lat_min+1]);%[km]
    DLAT=DDYY/DYWINDOW;%%%conversion in lat degree @lon_min of DDYY

    %%% longitude and latitude of points of the spiral
    lonspir=lon_min+DLON;
    latspir=lat_min+DLAT;
    
    %%
    %===================================%
    %- Plot Spiral on the first figure -%
    %===================================%
    figure(fid1); hold on;
    
%%%points of the spiral
    m_plot(lonspir,latspir,'k-');
    %%% label with points numers
     lonr = lon_max+(lon_max-lon_min)/10;
     latr = lat_max;
    [trash,irmax]=size(lonspir);
    for ir=1:irmax
        %AD new format and order
        m_text(lonr+.1, latr-.45 - ((ir-1) * 0.05),...
            [num2str(ir,'point# %3.0f'),'     ',num2str(lonspir(irmax+1-ir),'%5.2f'),...
            ' - ', num2str(latspir(irmax+1-ir),'%5.2f')]);
        m_text(lonspir(ir), latspir(ir), num2str(irmax+1-ir),...
            'Color','r','BackgroundColor',[.7 .9 .7],...
            'FontSize',8);
    end
    %%%center of the spiral
    m_plot(lonc,latc,'k*');
     
     hold on;
    
     totdistanceNM=totdistanceKM/1.852;
%AD     
skip=(latr -lat_min)/15;
    m_text(lonr,latr,['\bf{totdistanceNM: ',num2str(totdistanceNM),' [nm]}']);
    m_text(lonr,latr-skip,['\bf{ext-xlon: '     ,num2str(ext_xlon),' [km]}']);
    m_text(lonr,latr-2*skip,['\bf{ratio: '        ,num2str(ratio),' [ ]}']);
    m_text(lonr,latr-3*skip,['\bf{rotangle: '     ,num2str(rotangle),' [deg]}']);
    m_text(lonr,latr-4*skip,'\bf{Spiral lon - lat: [deg]}');
    

    %%
    %==============================%
    %- Save results in ASCII file -%
    %==============================%
    %- open the file with write permission -%
    fn=strcat(...
        'spiral_',...
        num2str(totdistanceNM),'_',... %AD KM -> NM
        num2str(ext_xlon),'_',...
        num2str(ratio),'_',...
        num2str(rotangle),'.txt');
    
    fid = fopen(fn,'w');
    fprintf(fid,'LATEX2010 CRUISE\r\n')
    string=['Sampling Spiral of ',date,'\r\n'];
    fprintf(fid,string)
    
    
%AD
    for ir=1:irmax
%        fprintf(fid, '%5.0f %12.4f %12.4f\r\n', [ir lonspir(irmax+1-ir) latspir(irmax+1-ir)]);
        fprintf(fid, '%5.0f %8.0fN %8.3f  %12.0fE %8.3f\r\n',...
                [ir fix(lonspir(irmax+1-ir)) (lonspir(irmax+1-ir) - fix(lonspir(irmax+1-ir)))*60 ...
                    fix(latspir(irmax+1-ir)) (latspir(irmax+1-ir) - fix(latspir(irmax+1-ir)))*60 ]);
    end
    
    %NG:     edit SamplingSpiralLatLon.txt
    
    fclose(fid);
    
    %%
    %==================================%
    %- Print figures in graphic files -%
    %==================================%
    orient landscape;
    fig_fn=strcat(...
        'spriral_',...
        num2str(totdistanceNM),'_',... %AD KM -> NM
        num2str(ext_xlon),'_',...
        num2str(ratio),'_',...
        num2str(rotangle),'.tif');
    
    print('-dtiff',fig_fn);
end


