%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% Script for draw a geographical map with 
%%% measured current vectors
%%%
%%% INPUT : coastline .mat file
%%%
%%% OUTPUT: m_map figure of ADCP current
%%%
%%% ALGORITHM: calcuate de projection and
%%%            plot the FSLE manifolds
%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% 19/09/2010 : andrea.doglioli@univmed.fr: update for compatibility with
%%%              the others tools
%%% 17/09/2010 : ziyuan.hu@univmed.fr
%%%              francesco.nencioli@univmed.fr
%%%              marion.kersale@univmed.fr
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
help map_ADCP
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
clear; close all;

% Choose the day of FSLE
year=2010;
month=9;
day=17;

FSLEdirin=sprintf('../FSLE_MODIS_Francesco/'); % To be changed to relative path


%%% choose parameter for ADCP
interval=[datenum(2010,9,20,17,0,0) datenum(2010,9,21,2,0,0)];%datenum(2010,9,8,5,0,0)];

depth=11 ;%[m] positive

myopt='b';
myscale=5;
legend_unit=0.2;
legend_lon=4.;
legend_lat=42.20;

% Choose map boundaries
lonmin=3.;
lonmax=4.5;
latmin=42.;
latmax=43.1;


% Path to ADCP file
dirin='../ADCP_Tethys/'; % To be changed to relative path
fname='final_ADCP_Saved.mat';

% Plot the figures
figure(1)
hold on; 
m_proj('mercator','lon',[lonmin lonmax],'lat',[latmin latmax])
m_grid('box','fancy','tickdir','in');
%

% FSLE Choose the day
year=2010;
month=9;
day=19;

plot_FSLE(FSLEdirin,year,month,day)

%%%%%%%%%%%%%%%%%%%%%%%
plot_ADCP(dirin,fname,interval,depth,myopt,myscale,legend_unit,legend_lon,legend_lat);
%%%%%%%%%%%%%%%%%%%%%%%

%
m_usercoast('GOL.mat','patch',[0.6 0.6 0.6]);
xlabel('Longtitude');
ylabel('Latitude');

%%%% HIGH RES BATHYMETRY
plot_BATHY('../BATHYMETRY_NWMED/',[200 500]);

%title(['Latex2010 ADCP @ ',num2str(abs(depth)),' m and FSLE for the ',datestr(datenum(year,month,day))]);

%print(1,[dirout,fname(1:14),'_transect_',num2str(nbt(i)),'.png'],'-dpng','-r200');


print(1,'map_FSLE_ADCP.png','-dpng','-r200');

disp(' ');
disp('----- END ---')

