%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% function [next_lon next_lat lon_end lat_end]=plot_buoy_update(dirin,chosen_id,myopt,period,next_d,next_h,next_m)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%
%%%  plot_buoy_update.m
%%%  this subfunction plots the future positon of the buoys estimated with
%%%  buoy_update.m, and the last part of the buoy track defined by period
%%%  Files with buoy positions in dirin are provided by Nicolas Martin
%%%
%%%  Adapted from plot_ARGOS_buoys
%%%
%%% Francesco Nencioli & Marion Kersale - 14/09/2010
%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
function [next_lon next_lat lon_end lat_end]=plot_buoy_update(dirin,chosen_id,myopt,period,next_d,next_h,next_m)



% time from now from which the buoy trajectory is plotted
time_last=datenum(now)-(period/24);

% computes future position
% load full list of files with buoy position
[time_id,lat,lon,drifter_id]=load_Argos_buoys(dirin);

% lat and lon vectors of the buoy defined by chosen_id
lon_id=lon(find(drifter_id==chosen_id));
lat_id=lat(find(drifter_id==chosen_id));
% time info of the buoy
time_id=time_id(find(drifter_id==chosen_id));

% keep only info more recent than time_last
lon_id=lon_id(time_id>=time_last);
lat_id=lat_id(time_id>=time_last);
time_id=time_id(time_id>=time_last);

% compute velocity from point to point (not output!!!)
ds=m_lldist(lon_id,lat_id);
dt=diff(time_id);
vel=(ds*100000)./(dt*24*60*60);
mean_v=mean(vel);
% compute average velocity using first and last point of hte trajectory
dS=m_lldist([lon_id(1) lon_id(end)],[lat_id(1),lat_id(end)]);
dT=time_id(end)-time_id(1);
Vel=dS./dT;
Vel_cm_sec=(dS*100000)./(dT*24*60*60);
% compute bouy direction
dx=m_lldist([lon_id(1) lon_id(end)],[lat(1) lat(1)]);
dy=m_lldist([lon_id(1) lon_id(1)],[lat_id(1) lat_id(end)]);
angle=atan(dy/dx);
if lon_id(1)>lon_id(end) & lat_id(1)<lat_id(end)
	angle=pi-angle;
elseif lon_id(1)>lon_id(end) & lat_id(1)>lat_id(end)
	angle=pi+angle;
elseif lon_id(1)<lon_id(end) & lat_id(1)>lat_id(end)
	angle=2*pi-angle;
end
% converson from date to number of days of the time at which the new
% position will be estimated
% IMPORTANT: Since we're using it for latex10 year and month are fixed to 2010 and
% 9!!!!!!!
time_next=datenum(2010,9,next_d,next_h,next_m,0);
% compute future distance (km) travelled
dist=Vel*(time_next-time_id(end));
% decompose distance in x and y dir
dY=dist*sin(angle);
dX=dist*cos(angle);
% first convert km to deg latitude (constant with longitude)
km2lat=m_lldist([lon_id(1) lon_id(1)],[lat_id(1) lat_id(1)+1]);
dlat=dY/km2lat;
next_lat=lat_id(end)+dlat;
% then convert km tolongitude at the updated latitude (km2lon varies with
% latitude)
km2lon=m_lldist([lon_id(end) lon_id(end)+1],[next_lat next_lat]);
dlon=dX/km2lon;
next_lon=lon_id(end)+dlon;


% Last position of the buoy
lon_end=lon_id(end);
lat_end=lat_id(end);

% plot the trajectory and the estimated position in the future
m_plot(next_lon,next_lat,myopt,'markersize',10,'linewidth',1);

m_text(next_lon,next_lat,datestr(time_next,'  dd/mm HH:MM  '),'HorizontalAlignment','Right');

%m_text(next_lon,next_lat,num2str(chosen_id));


%display position
disp(' ');
disp('--- forecasted position ---');
disp(['buoy #',num2str(chosen_id)]);
next_lon
decideg_to_degmin(next_lon,'lon');
next_lat
decideg_to_degmin(next_lat,'lat');
disp('---------------------------');


return
