%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% function [time,lon,lat,u,v]=plot_ADCP_track(dirin,fname,interval,mydepth,col)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
%  plot_ADCP_track.m
%  this function reads the position from the ADCP file ([dirin,fname])
%  and plot the ADCP track for the specified t-interval (interval)
%  with the specified color (col)
%
% interval=time interva in day of the trajectory
% col = color used to plot the track
%       (default is 'k')
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% 15/09/2011 : francesco.nencioli@univm-amu.fr
% 19/09/2010 : ziyuan.hu@univmed.fr & andrea.doglioli@univmed.fr
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function [time,lon,lat,u,v]=plot_ADCP_track(dirin,fname,interval,mydepth,col)

%==================================
if nargin<5
	col='k';
end
%==================================

load([dirin,fname]);

indexes=find(time>=interval(1) & time<=interval(2)); 

indexz=find(depth==mydepth);
while isempty(indexz)==1
    disp('The chosen depth is not available!');
    disp('Please, choose one of the following available depths :');
    disp(num2str(depth'));
    mydepth=input(': ');
    indexz=find(depth==mydepth);
end

lon=lon(indexes);
lat=lat(indexes);
time=time(indexes);%[days]

%==================================
%%% to have a scaled vector with respect the legend
% m_line(lon,lat,'color','k','linewidth',2);
% m_plot(lon(1),lat(1),'xk','linewidth',2);
% m_plot(lon(end),lat(end),'ok','linewidth',2);

m_line(lon,lat,'color',col,'linewidth',2);
m_plot(lon(1),lat(1),'x','color',col,'linewidth',2);
m_plot(lon(end),lat(end),'o','color',col,'linewidth',2);
%==================================
return
