%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%   LATEX00 track plotter    %%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% This  script  plots  the boat and buoy tracks in 
% lat/lon  coordinate   system    togheter    with
% buoy  track in the lagrangian  reference  system 
% of the buoy.
% This is done for both spiral and radiateur tests
% effectued  during  LATEX00  cruise in  june 2007
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% 31/03/11 AD: figures for EGU poster
% 06/07/07 AD: first version with commented lines 
%              for sensivity tests
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% input : save_spir_1162007_sansNaN.asc
%         concat_radiateur_sansNaN.asc
%
% output: one .eps file
%
% remarks: M_MAP package is required
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
clear;close all;
%
%help reconstitution
% ccode=input(' color code ? [1(deafult) 2 3] ');
% if isempty(ccode)==1
%  ccode=1;
% end
%
%%% M_MAP SETUP FOR STUDY AREA
m_proj('mercator','lon',[5.15 5.25],'lat',[42.99 43.06])
%m_gshhs_h('save','GoL'); 
%%% uncomment the line above the first time you run the script
%%% it creates GoL.mat file. When it is uncomment the script
%%% is very slow (more in M_MAP guide)
%
%%% DATA LOADING
for iplot=1:2;
 if iplot==1
  load ArgosLagrangianTests2007\save_spir_1162007_sansNaN.asc
  mm=save_spir_1162007_sansNaN;
 elseif iplot==2
  load ArgosLagrangianTests2007\concat_radiateur_sansNaN.asc
  mm=concat_radiateur_sansNaN;
 end%if iplot
 
time=mm(:,1); % time [sec]
latb=mm(:,2); % buoy   latitude during time
lonb=mm(:,3); %   "    longitude   "    "
latv=mm(:,5); % vessel latitude during time
lonv=mm(:,6); %   "    longitude   "    "
clear mm

%%% COMPUTATION OF VESSEL LAGRANGIAN POSITIONS
[itmax,trash]=size(time);
for it=1:itmax;
%    
% distx(it)=m_lldist([lonb(it) lonv(it)],[latb(it) latb(it)])./1000; % [km]
% disty(it)=m_lldist([lonb(it) lonb(it)],[latb(it) latv(it)])./1000; % [km]
%
% distx(it)=m_lldist([lonv(it) lonb(it)],[latb(it) latb(it)])./1000; % [km]
% disty(it)=m_lldist([lonb(it) lonb(it)],[latv(it) latb(it)])./1000; % [km]
%
% distx(it)=m_lldist([lonb(it) lonv(it)],[latv(it) latv(it)])./1000; % [km]
% disty(it)=m_lldist([lonv(it) lonv(it)],[latb(it) latv(it)])./1000; % [km]
%
%%% lines above have been used for sensitivity tests, then commented
%
 distx(it)=m_lldist([lonv(it) lonb(it)],[latb(it) latb(it)])%./1000; % [km]
 disty(it)=m_lldist([lonv(it) lonv(it)],[latv(it) latb(it)])%./1000; % [km]
%
end %for it
%
%signx=lonb-lonv; %%% uncorrect sign that produces 180^o rotation
signx=lonv-lonb;
signx(find(signx>=0))=1;
signx(find(signx< 0))=-1;
distx=distx.*signx';
%
%signy=latb-latv; %%% uncorrect sign that produces 180^o rotation
signy=latv-latb;
signy(find(signy>=0))=1;
signy(find(signy< 0))=-1;
disty=disty.*signy';
%
%%% PLOTTING
%
%figure(iplot);
%subplot(1,2,1);hold on;
figure(1)
%subplot(2,2,2*iplot-1);
hold on;
%
title('Vessel (blue) - Buoy (green) tracks')
m_usercoast('GoL','patch',[.8 .8 .8])
m_line(lonb,latb,'color','g','LineWidth',4);
m_plot(lonb,latb,'.g','MarkerSize',8);

m_line(lonv,latv,'color','b','LineWidth',4);
m_grid('box','fancy');
%title({IridiumDir(10:end);'Vessel (blue) - Buoy (green) tracks'})
title('Vessel (blue) - Buoy (green) tracks')
xlabel('longitude');
ylabel('latitude');

orient portrait;
%print('-dtiff',[IridiumDir,'\Buoy_Vessel_SF6_lagrangian_spiral_',...
%                datestr(now,30),'.tif']);
%print('-dtiff',['D:\Andrea\Latex_2010\Abstract_EGU\Fig1_',datestr(now,30),'.tif']);
print('-dtiff',['figures\Lagrangian_Reconstitution_Fig1_',datestr(now,30),'.tif']);

close
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

figure(2)
%subplot(2,2,2);hold on;
%subplot(2,2,2*iplot);
hold on;

% Plot expected route
 if iplot==1
  spirale_in_carte_4egu
 elseif iplot==2
   radiateur_in_carte_4egu
 end%if iplot

%plot(xx,yy,'r-','LineWidth',4)

hold on;
plot(distx,disty,'-b','LineWidth',4)
axis('square');

hold on;
plot(0,0,'or');
text(distx(end),disty(end),'end','backgroundColor','g')


%title({IridiumDir(10:end);'vessel track in lagrangian reference'});
title('expected (red) and obtained (blue) vessel track in the Lagrangian reference frame')
xlabel('Distance [km]');
ylabel('Distance [km]');
set(gca,'Linewidth',2)
grid on
box on

%print('-dtiff',[IridiumDir,'\Buoy_Vessel_SF6_lagrangian_spiral_',...
%                datestr(now,30),'.tif']);
%print('-dtiff',['D:\Andrea\Latex_2010\Abstract_EGU\Fig2_',datestr(now,30),'.tif']);
orient portrait;
print('-dtiff',['figures\Lagrangian_Reconstitution_Fig2_',datestr(now,30),'.tif']);

pause
close
end%for iplot
%
disp(' ')
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%